; smartear.nsi
;
; This script will generate an installer that installs a gaim plug-in.

;--------------------------------

; Uncomment the next line to enable auto Gaim download
; !define GAIM_AUTOINSTALL

; The name of the installer
Name "SmartEar Plugin"

; The file to write
OutFile "smartear.exe"

; The default installation directory
InstallDir $PROGRAMFILES\gaim\

; detect gaim path from uninstall string if available
InstallDirRegKey HKLM \
	"Software\Microsoft\Windows\CurrentVersion\Uninstall\Gaim" \
	"UninstallString"

; automatically close the installer when done.
AutoCloseWindow true

; hide the "show details" box
ShowInstDetails nevershow

;--------------------------------

; The stuff to install

Section ""

!ifdef GAIM_AUTOINSTALL
  Call MakeSureIGotGaim
!endif

  SetOutPath $INSTDIR\Plugins

  ; File to extract
  File "smartear.dll"

  ; prompt user, and if they select yes, go to YesGaimInstall
  MessageBox MB_OK|MB_ICONINFORMATION \
             "SmartEar Gaim plugin installed in $INSTDIR\plugins. Go to Tools->Preferences->Plugins from Gaim to configure it." 
SectionEnd

;--------------------------------

Function .onVerifyInstDir

!ifndef GAIM_AUTOINSTALL

  ;Check for Gaim installation

  IfFileExists $INSTDIR\gaim.exe Good
    Abort
  Good:

!endif ; GAIM_AUTOINSTALL

FunctionEnd

!ifdef GAIM_AUTOINSTALL

Function GetGaimInstPath

  Push $0
  Push $1
  Push $2
  ReadRegStr $0 HKLM \
	"Software\Microsoft\Windows\CurrentVersion\Uninstall\Gaim" \
	"UninstallString"
  StrCmp $0 "" fin

    StrCpy $1 $0 1 0 ; get firstchar
    StrCmp $1 '"' "" getparent 
      ; if first char is ", let's remove "'s first.
      StrCpy $0 $0 "" 1
      StrCpy $1 0
      rqloop:
        StrCpy $2 $0 1 $1
        StrCmp $2 '"' rqdone
        StrCmp $2 "" rqdone
        IntOp $1 $1 + 1
        Goto rqloop
      rqdone:
      StrCpy $0 $0 $1
    getparent:
    ; the uninstall string goes to an EXE, let's get the directory.
    StrCpy $1 -1
    gploop:
      StrCpy $2 $0 1 $1
      StrCmp $2 "" gpexit
      StrCmp $2 "\" gpexit
      IntOp $1 $1 - 1
      Goto gploop
    gpexit:
    StrCpy $0 $0 $1

    StrCmp $0 "" fin
    IfFileExists $0\gaim.exe fin
      StrCpy $0 ""
  fin:
  Pop $2
  Pop $1
  Exch $0
  
FunctionEnd


Function MakeSureIGotGaim

  Call GetGaimInstPath

  Pop $0
  StrCmp $0 "" getgaim
    Return
    
  getgaim:
  
  ; prompt user, and if they select yes, go to YesGaimInstall
  MessageBox MB_YESNO|MB_ICONQUESTION \
             "It appears you don't have gaim installed. Would you like me to download and install it?" \
             IDYES YesGaimInstall
	Abort
  YesGaimInstall:

  Call ConnectInternet ;Make an internet connection (if no connection available)
  
  StrCpy $2 "$TEMP\gaim-installer.exe"
  NSISdl::download http://easynews.dl.sourceforge.net/sourceforge/gaim/gaim-0.65.exe $2
  Pop $0
  StrCmp $0 success success
    SetDetailsView show
    DetailPrint "download failed: $0"
    Abort
  success:
    ExecWait '"$2" /S'
    Delete $2
    Call GetGaimInstPath
    Pop $0
    StrCmp $0 "" skip
    StrCpy $INSTDIR $0
  skip:
  
FunctionEnd

Function ConnectInternet
    
  ClearErrors
  Dialer::AttemptConnect
  IfErrors noie3
    
  Pop $R0
  StrCmp $R0 "online" connected
    MessageBox MB_OK|MB_ICONSTOP "Cannot connect to the internet."
    Quit
  
  noie3:
  
  ; IE3 not installed
  MessageBox MB_OK|MB_ICONINFORMATION "Please connect to the internet now."
  
  connected:
  
FunctionEnd

!endif ; GAIM_AUTOINSTALL
